@@ -9,8 +9,6 @@
 #' @param var_list the list of covariates to be fitted into the model.
 #' @param copula specify the copula family.
 #' @param m.dist specify the marginal baseline distribution.
-#' @param n.cons number of pieces, only for \code{m.dist = "Piecewise"}.
-#' Default is 4.
 #' @param method optimization method (see \code{?optim}); default is \code{"BFGS"};
 #' also can be \code{"Newton"} (see \code{?nlm}).
 #' @param iter number of iterations when \code{method = "Newton"};
@@ -76,10 +74,9 @@
 #'
 #'
 #' The supported marginal distributions are \code{"Weibull"} (proportional hazards),
-#' \code{"Gompertz"} (proportional hazards), \code{"Piecewise"} (proportional hazards)
-#' and \code{"Loglogistic"} (proportional odds).
-#' These marginal distributions follow the standard parameterization in Wikipedia.
-#' We also assume the same baseline parameters between two margins. \cr
+#' \code{"Gompertz"} (proportional hazards) and \code{"Loglogistic"} (proportional odds).
+#' These marginal distributions are listed below and
+#' we also assume the same baseline parameters between two margins. \cr
 #'
 #' The Weibull (PH) survival distribution is \deqn{\exp \{-(t/\lambda)^k  e^{Z^{\top}\beta}\},}
 #' with \eqn{\lambda > 0} as scale and \eqn{k > 0} as shape.
@@ -87,9 +84,6 @@
 #' The Gompertz (PH) survival distribution is \deqn{\exp \{-\frac{b}{a}(e^{at}-1) e^{Z^{\top}\beta}\},}
 #' with \eqn{a > 0} as shape and \eqn{b > 0} as rate.
 #'
-#' The Piecewise constant (PH) survival distribution is \deqn{\exp \{-\int_{0}^{t} \lambda_{0}(s) ds \ e^{Z^{\top}\beta}\},}
-#' with \eqn{ \lambda_{0}(s) = \rho_{k}} for \eqn{s \in (a_{k-1},a_k]}.
-#'
 #' The Loglogistic (PO) survival distribution is \deqn{\{1+(t/\lambda)^{k} e^{Z^{\top}\beta} \}^{-1},}
 #' with \eqn{\lambda > 0} as scale and \eqn{k > 0} as shape. \cr
 #'
@@ -101,7 +95,7 @@
 #' @return a \code{CopulaCenR} object summarizing the model.
 #' Can be used as an input to general \code{S3} methods including
 #' \code{summary}, \code{print}, \code{plot}, \code{lines},
-#' \code{coef}, \code{logLik], \code{AIC},
+#' \code{coef}, \code{logLik}, \code{AIC},
 #' \code{BIC}, \code{fitted}, \code{predict}.
 #'
 #' @examples
@@ -115,7 +109,7 @@
 
 
 rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
-                          n.cons = 4, method = "BFGS", iter = 500, stepsize = 1e-6,
+                          method = "BFGS", iter = 500, stepsize = 1e-6,
                           control = list()) {
 
 
@@ -135,8 +129,8 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
     stop('copula must be one of "Clayton","Gumbel","Copula2","Frank","Joe","AMH"')
   }
 
-  if (!m.dist %in% c("Weibull","Loglogistic","Gompertz","Piecewise"))	{
-    stop('m.dist must be one of "Weibull","Loglogistic","Gompertz","Piecewise"')
+  if (!m.dist %in% c("Weibull","Loglogistic","Gompertz"))	{
+    stop('m.dist must be one of "Weibull","Loglogistic","Gompertz"')
   }
 
   if (!method %in% c("Newton","Nelder-Mead","BFGS","CG","SANN"))	{
@@ -158,8 +152,6 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
                   obs_time = c(indata1$obs_time, indata2$obs_time),
                   status = c(indata1$status, indata2$status),
                   rbind(x1, x2))
-  quantiles <- NULL # for piecewise only
-
 
   ###################################
   ############ Step 1a ##############
@@ -200,76 +192,53 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
 
   }
 
-  if (m.dist == "Piecewise") {
-
-    quantiles <- c(0, quantile(data[data[,"status"]==1,"obs_time"],
-                               seq(1, (n.cons-1), 1)/n.cons),
-                   max(data[,"obs_time"])
-                   )
-    # starting values approximated by Weibull
-    M <- survreg(as.formula(paste0("Surv(obs_time,status)~",
-                                   paste0(var_list, collapse = "+"),
-                                   "+cluster(id)")),
-                 data = x, dist = "weibull", scale = 2)
-    lambda_ini<- rep(exp(-summary(M)$coefficients[1]), n.cons)
-    beta_ini <- -summary(M)$coefficients[2:(length(var_list) + 1)]
-
-  }
-
   ###################################
   ############ Step 1b ##############
   ###################################
   if (copula == "AMH") {
-    eta_ini<- 0.5
+    eta_ini<- 0
   }
 
   else if (copula == "Copula2") {
-    eta_ini <- c(1, 1)
+    eta_ini <- c(0, 0)
   }
 
   else {
-    eta_ini <- 2
+    eta_ini <- 0 # log-scale
   }
 
   if (method == "Newton") {
 
-    if (m.dist == "Piecewise") {
-      fit0 <- nlm(rc_copula_log_lik_eta, p=eta_ini, p2 = c(lambda_ini,beta_ini),
-                quantiles = quantiles, x1 = x1, x2 = x2, indata1 = indata1,
-                indata2 = indata2, iterlim = iter, steptol = stepsize,
-                copula = copula, m.dist = m.dist)
-    } else {
-      fit0 <- nlm(rc_copula_log_lik_eta, p = eta_ini,
+    fit0 <- nlm(rc_copula_log_lik_eta, p = eta_ini,
                   p2 = c(lambda_ini,k_ini,beta_ini),
                   x1 = x1, x2 = x2, indata1 = indata1,indata2 = indata2,
                   iterlim = iter, steptol = stepsize, copula = copula,
                   m.dist = m.dist)
-    }
 
-    eta_ini <- fit0$estimate
+    eta_ini <- exp(fit0$estimate) # anti-log
 
   } else {
 
-    if (m.dist == "Piecewise") {
-      fit0 <- optim(par = eta_ini, rc_copula_log_lik_eta,
-                    p2 = c(lambda_ini, beta_ini),
-                    method = method,  control = control, hessian = FALSE,
-                    quantiles = quantiles,x1 = x1, x2 = x2,indata1 = indata1,
-                    indata2 = indata2, copula = copula, m.dist = m.dist)
-    } else {
-      fit0 <- optim(par = eta_ini, rc_copula_log_lik_eta,
+    fit0 <- optim(par = eta_ini, rc_copula_log_lik_eta,
                     p2 = c(lambda_ini,k_ini,beta_ini),
                     method = method,  control = control, hessian = FALSE,
                     x1 = x1, x2 = x2,indata1 = indata1,indata2 = indata2,
                     copula = copula, m.dist = m.dist)
-    }
-    eta_ini <- fit0$par
+
+    eta_ini <- exp(fit0$par) # anti-log
   }
 
 
 
+  # Quality check for step 1b estimates
   # AMH shall be between 0 and 1
   if (copula == "AMH" & eta_ini[1] > 1) {eta_ini <- 0.5}
+  # Gumbel shall be >= 1
+  if (copula == "Gumbel" & eta_ini[1] < 1) {eta_ini <- 1}
+  # Joe shall be >= 1
+  if (copula == "Joe" & eta_ini[1] < 1) {eta_ini <- 1}
+  # Copula2 alpha shall be between 0 and 1
+  if (copula == "Copula2" & eta_ini[1] > 1) {eta_ini[1] <- 0.5}
 
 
   ###################################
@@ -277,7 +246,6 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
   ###################################
 
   if (method == "Newton") {
-    if (m.dist != "Piecewise") {
       model_step2 <- nlm(rc_copula_log_lik, p = c(lambda_ini,k_ini,beta_ini,eta_ini),
                          x1 = x1, x2 = x2,indata1 = indata1,indata2 = indata2,
                          iterlim = iter, steptol = stepsize, hessian = T,
@@ -304,38 +272,10 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
                      indata2 = indata2, var_list = var_list,
                      estimates = model_step2$estimate, x1 = x1, x2 = x2,
                      inv_info = inv_info)
-    }
-
-    else if (m.dist == "Piecewise") {
-      model_step2 <- nlm(rc_copula_log_lik, p = c(lambda_ini,eta_ini,beta_ini),
-                         quantiles = quantiles, x1 = x1, x2 = x2,
-                         indata1 = indata1,indata2 = indata2,
-                         iterlim = iter, steptol = stepsize, hessian = T,
-                         copula = copula, m.dist = m.dist)
-      inv_info <- pseudoinverse(model_step2$hessian)
-      dih <- diag(inv_info)
-      dih[dih < 0] <- 0
-      se <- sqrt(dih)
-      beta <- model_step2$estimate # contains lambda, k, beta and eta
-      llk <- -1 * model_step2$minimum
-      AIC <- 2 * length(beta) - 2 * llk
-      stat <- (beta - 0)^2/se^2
-      pvalue <- pchisq(stat, 1, lower.tail=F)
-      summary <- cbind(beta, se, stat, pvalue)
-      rownames(summary) <- if (copula != "Copula2") c(paste0("pc",1:n.cons),"eta",var_list) else c(paste0("pc",1:n.cons),"alpha","kappa",var_list)
-      colnames(summary) <- c("estimate","SE","stat","pvalue")
-      code <- model_step2$code
-      output <- list(code = code, summary = summary, llk = llk, AIC = AIC,
-                     copula = copula, m.dist = m.dist, indata1 = indata1,
-                     indata2 = indata2, var_list = var_list,
-                     estimates = model_step2$estimate, x1 = x1, x2 = x2,
-                     n.cons = n.cons, quantiles = quantiles, inv_info = inv_info)
-    }
   }
 
 
   if (method != "Newton") {
-    if (m.dist != "Piecewise") {
       model_step2 <- optim(c(lambda_ini,k_ini,beta_ini,eta_ini), rc_copula_log_lik,
                          x1 = x1, x2 = x2,indata1 = indata1, indata2 = indata2,
                          hessian = T, method = method,  control = control,
@@ -362,34 +302,6 @@ rc_par_copula <- function(data, var_list, copula="Clayton", m.dist="Weibull",
                      indata2 = indata2, var_list = var_list,
                      estimates = model_step2$par, x1 = x1, x2 = x2,
                      inv_info = inv_info)
-    }
-
-    else if (m.dist == "Piecewise") {
-      model_step2 <- optim(c(lambda_ini,eta_ini,beta_ini), rc_copula_log_lik,
-                           quantiles = quantiles, x1 = x1, x2 = x2,
-                           indata1 = indata1, indata2 = indata2,
-                           hessian = T, method = method, control = control,
-                           copula = copula, m.dist = m.dist)
-
-      inv_info <- pseudoinverse(model_step2$hessian)
-      dih <- diag(inv_info)
-      dih[dih < 0] <- 0
-      se <- sqrt(dih)
-      beta <- model_step2$par # contains lambda, k, beta and eta
-      llk <- -1 * model_step2$value
-      AIC <- 2 * length(beta) - 2 * llk
-      stat <- (beta - 0)^2/se^2
-      pvalue <- pchisq(stat, 1, lower.tail=F)
-      summary <- cbind(beta, se, stat, pvalue)
-      rownames(summary) <- if (copula != "Copula2") c(paste0("pc",1:n.cons),"eta",var_list) else c(paste0("pc",1:n.cons),"alpha","kappa",var_list)
-      colnames(summary) <- c("estimate","SE","stat","pvalue")
-      code <- model_step2$convergence
-      output <- list(code = code, summary = summary, llk = llk, AIC = AIC,
-                     copula = copula, m.dist = m.dist,
-                     indata1 = indata1, indata2 = indata2, var_list = var_list,
-                     estimates = model_step2$par, x1 = x1, x2 = x2,
-                     n.cons = n.cons, quantiles = quantiles,inv_info = inv_info)
-    }
   }
 
   class(output) <- "CopulaCenR"
